function addScapScripts(webOSVersion) {
	console.log('Adding SCAP scripts');

	var scapFiles = ['configuration.js', 'deviceInfo.js', 'inputSource.js', 'power.js', 'signage.js', 'sound.js', 'storage.js', 'video.js', 'security.js', 'time.js', 'utility.js'];

	var webOSScapVersion = {
		'3.0': '1.4.5',
		'3.2': '1.5.10',
		'4.0': '1.6.5',
		'4.1': '1.7.4',
		'6.0.0': '1.8.0'
	};

	var lastScriptElement;

	for (var i = 0; i < scapFiles.length; i++) {
		var scriptPath = './webos/cordova-cd/' + webOSScapVersion[webOSVersion] + '/' + scapFiles[i];

		lastScriptElement = addScript(scriptPath);

		console.log('- ' + scriptPath);
	}

	lastScriptElement.onload = function () {
		var deviceInfo = new DeviceInfo();

		deviceInfo.getPlatformInfo(
			function () {
				startApplication();
			},
			function (error) {
				console.error('Cannot get platform information, so not able to start application', error);
			}
		);
	};
}

function loadDependencies() {
	console.log('WebOS version ' + window.webOSVersion);

	switch (window.webOSVersion) {
		case '3.0':
		case '3.2':
		case '4.0':
		case '4.1':
		case '6.0.0':
			addScapScripts(window.webOSVersion);
			break;
		default:
			console.error('No scap scripts supported for this version');
			break;
	}
}

// WebOS < 6.0
function requestByCustomJS() {
	new Custom().Signage.getwebOSVersion(
		function (result) {
			window.webOSVersion = result.webOSVersion;

			loadDependencies();
		},
		function (error) {
			console.error('Failed to get WebOS version by CustomJS, trying IDCAP in a moment (to prevent connectivity issues at startup). ([' + error.errorCode + '] ' + error.errorText + ')');

			addScript('./webos/cordova-cd/idcap.js');

			setTimeout(function() {
				requestByIDCAP();
			}, 1000);
		}
	);
}

// WebOS >= 6.0
function requestByIDCAP() {
	idcap.request('idcap://configuration/property/get', {
		parameters: {
			key: 'webos_version'
		},
		onSuccess: function (result) {
			window.webOSVersion = result.value;

			loadDependencies();
		},
		onFailure: function (error) {
			console.error('Failed to get WebOS version by IDCAP too. Cannot proceed now. (' + error.errorMessage + ')');
		}
	});
}

requestByCustomJS();
